<?php

function get_sitemap_urls($city) {

	$urls = [];

	// записи
	$arr_posts_exclude = [];
	$arr_terms_exclude = [];
	if(get_option('belingo_geo_exclude_posts')) {
		$arr_posts_exclude = get_option('belingo_geo_exclude_posts');
	}
	if(get_option('belingo_geo_exclude_terms')) {
		$arr_terms_exclude = get_option('belingo_geo_exclude_terms');
	}
	$query = new WP_Query([
		'post_type'=>'post',
		'posts_per_page'=>-1,
		'post_status'=>'publish',
		'post__not_in'=>$arr_posts_exclude,
		'category__not_in'=>$arr_terms_exclude
	]);
	foreach ($query->posts as $post_item) {
		if(!empty($post_item->post_name)) {
			$loc = get_the_permalink($post_item->ID);
			if(isset($_COOKIE['geo_city'])) {
				$loc = str_replace($_COOKIE['geo_city'], $city, $loc);
			}else{
				$loc = append_city_url($loc, $city);
			}
			$urls[] = [
				"loc" => $loc,
				"lastmod" => date('c',strtotime($post_item->post_modified))
			];
		}
	}

	// страницы
	$arr_pages_exclude = [];
	if(get_option('belingo_geo_exclude_pages')) {
		$arr_pages_exclude = get_option('belingo_geo_exclude_pages');
	}
	$query = new WP_Query([
		'post_type'=>'page',
		'posts_per_page'=>-1,
		'post_status'=>'publish',
		'post__not_in'=>$arr_pages_exclude
	]);
	foreach ($query->posts as $post_item) {
		if(!empty($post_item->post_name)) {
			if(get_option('page_on_front') != $post_item->ID) {
				$loc = get_the_permalink($post_item->ID);
				if(isset($_COOKIE['geo_city'])) {
					$loc = str_replace($_COOKIE['geo_city'], $city, $loc);
				}else{
					$loc = append_city_url($loc, $city);
				}
				$urls[] = [
					"loc" => $loc,
					"lastmod" => date('c',strtotime($post_item->post_modified))
				];
			}
		}
	}

	if(class_exists('WooCommerce')) {

		// товары
		$query = new WP_Query('post_type=product&posts_per_page=-1&post_status=publish');
		foreach ($query->posts as $post_item) {
			if(!empty($post_item->post_name)) {
				$loc = get_the_permalink($post_item->ID);
				if(isset($_COOKIE['geo_city'])) {
					$loc = str_replace($_COOKIE['geo_city'], $city, $loc);
				}else{
					$loc = append_city_url($loc, $city);
				}
				$urls[] = [
					"loc" => $loc,
					"lastmod" => date('c',strtotime($post_item->post_modified))
				];
			}
		}

		// категории
		$terms = get_terms('taxonomy=product_cat');
		foreach ($terms as $key => $term) {
			$loc = get_term_link($term->term_id);
			if(isset($_COOKIE['geo_city'])) {
				$loc = str_replace($_COOKIE['geo_city'], $city, $loc);
			}else{
				$loc = append_city_url($loc, $city);
			}
			$urls[] = [
				"loc" => $loc,
				"lastmod" => date('c',time())
			];
		}

	}
		
	return $urls;

}

function get_xml($urls) {

	$headers = [
			'HTTP/1.1 200 OK' => 200,
			'X-Robots-Tag: noindex, follow'  => '',
			'Content-Type: text/xml; charset=' . esc_attr( 'UTF-8' ) => '',
		];


	foreach ( $headers as $header => $status ) {
		if ( is_numeric( $status ) ) {
			header( $header, true, $status );
			continue;
		}
		header( $header, true );
	}

	echo '<?xml version="1.0" encoding="UTF-8"?>' . "\n" .
		 '<urlset xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:image="http://www.google.com/schemas/sitemap-image/1.1" '
			. 'xsi:schemaLocation="http://www.sitemaps.org/schemas/sitemap/0.9 http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd '
			. 'http://www.google.com/schemas/sitemap-image/1.1 http://www.google.com/schemas/sitemap-image/1.1/sitemap-image.xsd" '
			. 'xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . "\n";

	foreach ($urls as $key => $url) {
		echo get_xml_sitemap_url($url);
	}
		
	echo '</urlset>';

}

function get_xml_sitemap_url($url) {

	return '	<url>' . "\n" .
				'		<loc>'.$url['loc'].'</loc>' . "\n" .
				'		<lastmod>'.$url['lastmod'].'</lastmod>' . "\n" .
			  '	</url>' . "\n";

}

function get_xml_sitemap($url) {

	return '<sitemap>' . "\n" .
				'<loc>'.$url['loc'].'</loc>' . "\n" .
				'<lastmod>'.$url['lastmod'].'</lastmod>' . "\n" .
			  '</sitemap>' . "\n";

}

?>